@@ -3,21 +3,20 @@ import pathlib
 import logging
 
 import numpy as np
-import vtk
-from vtk import vtkImageData, vtkRectilinearGrid
-from vtk.util.numpy_support import numpy_to_vtk, vtk_to_numpy
 
 import pyvista
+from pyvista import _vtk
 from pyvista.utilities import abstract_class
-from .common import Common
+from .dataset import DataSet
 from .filters import _get_output, UniformGridFilters
 
+
 log = logging.getLogger(__name__)
 log.setLevel('CRITICAL')
 
 
 @abstract_class
-class Grid(Common):
+class Grid(DataSet):
     """A class full of common methods for non-pointset grids."""
 
     def __init__(self, *args, **kwargs):
@@ -42,12 +41,12 @@ class Grid(Common):
 
     def _get_attrs(self):
         """Return the representation methods (internal helper)."""
-        attrs = Common._get_attrs(self)
+        attrs = DataSet._get_attrs(self)
         attrs.append(("Dimensions", self.dimensions, "{:d}, {:d}, {:d}"))
         return attrs
 
 
-class RectilinearGrid(vtkRectilinearGrid, Grid):
+class RectilinearGrid(_vtk.vtkRectilinearGrid, Grid):
     """Extend the functionality of a vtk.vtkRectilinearGrid object.
 
     Can be initialized in several ways:
@@ -81,15 +80,15 @@ class RectilinearGrid(vtkRectilinearGrid, Grid):
 
     """
 
-    _READERS = {'.vtk': vtk.vtkRectilinearGridReader, '.vtr': vtk.vtkXMLRectilinearGridReader}
-    _WRITERS = {'.vtk': vtk.vtkRectilinearGridWriter, '.vtr': vtk.vtkXMLRectilinearGridWriter}
+    _WRITERS = {'.vtk': _vtk.vtkRectilinearGridWriter,
+                '.vtr': _vtk.vtkXMLRectilinearGridWriter}
 
     def __init__(self, *args, **kwargs):
         """Initialize the rectilinear grid."""
         super().__init__()
 
         if len(args) == 1:
-            if isinstance(args[0], vtk.vtkRectilinearGrid):
+            if isinstance(args[0], _vtk.vtkRectilinearGrid):
                 self.deep_copy(args[0])
             elif isinstance(args[0], (str, pathlib.Path)):
                 self._from_file(args[0])
@@ -115,11 +114,11 @@ class RectilinearGrid(vtkRectilinearGrid, Grid):
 
     def __repr__(self):
         """Return the default representation."""
-        return Common.__repr__(self)
+        return DataSet.__repr__(self)
 
     def __str__(self):
         """Return the str representation."""
-        return Common.__str__(self)
+        return DataSet.__str__(self)
 
     def _update_dimensions(self):
         """Update the dimensions if coordinates have changed."""
@@ -147,13 +146,13 @@ class RectilinearGrid(vtkRectilinearGrid, Grid):
         # Set the coordinates along each axial direction
         # Must at least be an x array
         x = np.unique(x.ravel())
-        self.SetXCoordinates(numpy_to_vtk(x))
+        self.SetXCoordinates(_vtk.numpy_to_vtk(x))
         if y is not None:
             y = np.unique(y.ravel())
-            self.SetYCoordinates(numpy_to_vtk(y))
+            self.SetYCoordinates(_vtk.numpy_to_vtk(y))
         if z is not None:
             z = np.unique(z.ravel())
-            self.SetZCoordinates(numpy_to_vtk(z))
+            self.SetZCoordinates(_vtk.numpy_to_vtk(z))
         # Ensure dimensions are properly set
         self._update_dimensions()
 
@@ -192,36 +191,36 @@ class RectilinearGrid(vtkRectilinearGrid, Grid):
     @property
     def x(self):
         """Get the coordinates along the X-direction."""
-        return vtk_to_numpy(self.GetXCoordinates())
+        return _vtk.vtk_to_numpy(self.GetXCoordinates())
 
     @x.setter
     def x(self, coords):
         """Set the coordinates along the X-direction."""
-        self.SetXCoordinates(numpy_to_vtk(coords))
+        self.SetXCoordinates(_vtk.numpy_to_vtk(coords))
         self._update_dimensions()
         self.Modified()
 
     @property
     def y(self):
         """Get the coordinates along the Y-direction."""
-        return vtk_to_numpy(self.GetYCoordinates())
+        return _vtk.vtk_to_numpy(self.GetYCoordinates())
 
     @y.setter
     def y(self, coords):
         """Set the coordinates along the Y-direction."""
-        self.SetYCoordinates(numpy_to_vtk(coords))
+        self.SetYCoordinates(_vtk.numpy_to_vtk(coords))
         self._update_dimensions()
         self.Modified()
 
     @property
     def z(self):
         """Get the coordinates along the Z-direction."""
-        return vtk_to_numpy(self.GetZCoordinates())
+        return _vtk.vtk_to_numpy(self.GetZCoordinates())
 
     @z.setter
     def z(self, coords):
         """Set the coordinates along the Z-direction."""
-        self.SetZCoordinates(numpy_to_vtk(coords))
+        self.SetZCoordinates(_vtk.numpy_to_vtk(coords))
         self._update_dimensions()
         self.Modified()
 
@@ -232,13 +231,13 @@ class RectilinearGrid(vtkRectilinearGrid, Grid):
 
     def cast_to_structured_grid(self):
         """Cast this rectilinear grid to a :class:`pyvista.StructuredGrid`."""
-        alg = vtk.vtkRectilinearGridToPointSet()
+        alg = _vtk.vtkRectilinearGridToPointSet()
         alg.SetInputData(self)
         alg.Update()
         return _get_output(alg)
 
 
-class UniformGrid(vtkImageData, Grid, UniformGridFilters):
+class UniformGrid(_vtk.vtkImageData, Grid, UniformGridFilters):
     """Extend the functionality of a vtk.vtkImageData object.
 
     Can be initialized in several ways:
@@ -277,15 +276,14 @@ class UniformGrid(vtkImageData, Grid, UniformGridFilters):
 
     """
 
-    _READERS = {'.vtk': vtk.vtkDataSetReader, '.vti': vtk.vtkXMLImageDataReader}
-    _WRITERS = {'.vtk': vtk.vtkDataSetWriter, '.vti': vtk.vtkXMLImageDataWriter}
+    _WRITERS = {'.vtk': _vtk.vtkDataSetWriter, '.vti': _vtk.vtkXMLImageDataWriter}
 
     def __init__(self, *args, **kwargs):
         """Initialize the uniform grid."""
         super().__init__()
 
         if len(args) == 1:
-            if isinstance(args[0], vtk.vtkImageData):
+            if isinstance(args[0], _vtk.vtkImageData):
                 self.deep_copy(args[0])
             elif isinstance(args[0], (str, pathlib.Path)):
                 self._from_file(args[0])
@@ -309,11 +307,11 @@ class UniformGrid(vtkImageData, Grid, UniformGridFilters):
 
     def __repr__(self):
         """Return the default representation."""
-        return Common.__repr__(self)
+        return DataSet.__repr__(self)
 
     def __str__(self):
         """Return the default str representation."""
-        return Common.__str__(self)
+        return DataSet.__str__(self)
 
     def _from_specs(self, dims, spacing=(1.0,1.0,1.0), origin=(0.0, 0.0, 0.0)):
         """Create VTK image data directly from numpy arrays.
@@ -424,7 +422,7 @@ class UniformGrid(vtkImageData, Grid, UniformGridFilters):
 
     def cast_to_structured_grid(self):
         """Cast this uniform grid to a :class:`pyvista.StructuredGrid`."""
-        alg = vtk.vtkImageToStructuredGrid()
+        alg = _vtk.vtkImageToStructuredGrid()
         alg.SetInputData(self)
         alg.Update()
         return _get_output(alg)
